FluentTextField class

Inheritance

Constructors

FluentTextField({Key? key, TextEditingController? controller, FocusNode? focusNode, TextInputType? keyboardType, TextInputAction? textInputAction, TextStyle? style, StrutStyle? strutStyle, TextDirection? textDirection, TextAlignVertical? textAlignVertical, bool? showCursor, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, int? minLines, int? maxLength, void onChanged(String)?, void onTap()?, void onTapOutside(PointerDownEvent)?, void onEditingComplete()?, List<TextInputFormatter>? inputFormatters, double? cursorHeight, Color? cursorColor, Brightness? keyboardAppearance, bool? enableInteractiveSelection, TextSelectionControls? selectionControls, ScrollPhysics? scrollPhysics, Iterable<String>? autofillHints, ScrollController? scrollController, String? restorationId, MaxLengthEnforcement? maxLengthEnforcement, InputDecoration? decoration, Color? highlightColor, Color? unfocusedColor, Widget contextMenuBuilder(BuildContext, EditableTextState)?, TextMagnifierConfiguration? magnifierConfiguration, SpellCheckConfiguration? spellCheckConfiguration, TextCapitalization textCapitalization = TextCapitalization.none, TextAlign textAlign = TextAlign.start, bool autofocus = false, bool readOnly = false, String obscuringCharacter = '•', bool obscureText = false, bool autocorrect = true, bool enableSuggestions = true, int? maxLines = 1, bool expands = false, EdgeInsetsGeometry padding = kTextBoxPadding, bool enabled = true, double cursorWidth = 2.0, Radius cursorRadius = const Radius.circular(2.0), EdgeInsets scrollPadding = const EdgeInsets.all(20.0), Clip clipBehavior = Clip.antiAlias, OverlayVisibilityMode prefixMode = OverlayVisibilityMode.always, OverlayVisibilityMode suffixMode = OverlayVisibilityMode.always, DragStartBehavior dragStartBehavior = DragStartBehavior.start, BoxHeightStyle selectionHeightStyle = BoxHeightStyle.tight, BoxWidthStyle selectionWidthStyle = BoxWidthStyle.tight, bool enableIMEPersonalizedLearning = true, bool stylusHandwritingEnabled = true, WidgetStateProperty<BoxDecoration>? boxDecoration, void onSubmitted(String)?})
const

Properties

autocorrect → bool
final
autofillHints → Iterable<String>?
final
autofocus → bool
final
boxDecoration → WidgetStateProperty<BoxDecoration>?
final
clipBehavior → Clip
final
contextMenuBuilder → Widget Function(BuildContext, EditableTextState)?
final
controller → TextEditingController?
final
cursorColor → Color?
final
cursorHeight → double?
final
cursorRadius → Radius
final
cursorWidth → double
final
decoration → InputDecoration?
final
dragStartBehavior → DragStartBehavior
final
enabled → bool
final
enableIMEPersonalizedLearning → bool
final
enableInteractiveSelection → bool?
final
enableSuggestions → bool
final
expands → bool
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
highlightColor → Color?
final
inputFormatters → List<TextInputFormatter>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance → Brightness?
final
keyboardType → TextInputType?
final
magnifierConfiguration → TextMagnifierConfiguration?
final
maxLength → int?
final
maxLengthEnforcement → MaxLengthEnforcement?
final
maxLines → int?
final
minLines → int?
final
obscureText → bool
final
obscuringCharacter → String
final
onChanged → void Function(String)?
final
onEditingComplete → void Function()?
final
onSubmitted → void Function(String)?
final
onTap → void Function()?
final
onTapOutside → void Function(PointerDownEvent)?
final
padding → EdgeInsetsGeometry
final
prefixMode → OverlayVisibilityMode
final
readOnly → bool
final
restorationId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController → ScrollController?
final
scrollPadding → EdgeInsets
final
scrollPhysics → ScrollPhysics?
final
selectionControls → TextSelectionControls?
final
selectionHeightStyle → BoxHeightStyle
final
selectionWidthStyle → BoxWidthStyle
final
showCursor → bool?
final
smartDashesType → SmartDashesType?
final
smartQuotesType → SmartQuotesType?
final
spellCheckConfiguration → SpellCheckConfiguration?
final
strutStyle → StrutStyle?
final
style → TextStyle?
final
stylusHandwritingEnabled → bool
final
suffixMode → OverlayVisibilityMode
final
textAlign → TextAlign
final
textAlignVertical → TextAlignVertical?
final
textCapitalization → TextCapitalization
final
textDirection → TextDirection?
final
textInputAction → TextInputAction?
final
unfocusedColor → Color?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited